@@ -6,7 +6,7 @@ function(filename) {
 ## version: A0.2
 ## input: filename of an existing netcdf-file
 ## output: ncdf object
-	library("ncdf")
+#	library("ncdf")
 	ncdfobj<-open.ncdf(filename)
 	return(ncdfobj)
 }
